@@ -610,8 +610,7 @@ def test_arraysize(cursor):
 
 
 def test_setinputsizes(cursor):
-    cursor.setinputsizes((25,))
-    _paraminsert(cursor)  # Make sure cursor still works
+    cursor.setinputsizes(25)
 
 
 def test_setoutputsize_basic(cursor):
